@@ -102,7 +102,6 @@ test_that("expected errors", {
   expect_error(tableSurvival(surv, times = c(1,2,3), timeScale = "day"))
 
   CDMConnector::cdmDisconnect(cdm)
-
 })
 
 test_that("timeScale months", {
@@ -129,3 +128,12 @@ test_that("timeScale months", {
 
   CDMConnector::cdmDisconnect(cdm)
 })
+
+test_that("timeScale and times incompatible", {
+  cdm <- mockMGUS2cdm()
+  surv <- estimateSingleEventSurvival(cdm,
+                                      targetCohortTable = "mgus_diagnosis",
+                                      outcomeCohortTable = "death_cohort")
+  expect_no_error(tableSurvival(surv, times = c(50), timeScale = "years"))
+  CDMConnector::cdmDisconnect(cdm)
+})
